@@ -1,4 +1,4 @@
-/*  $Id: xfce_theme_draw.c 400 2005-03-09 21:24:56Z olivier $
+/*  $Id: xfce_theme_draw.c 23993 2006-11-27 18:37:27Z olivier $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -581,11 +581,11 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
             {
                 if(DETAIL("trough"))
                 {
-                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x, y, x + width - 1, y);
-                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x, y, x, y + height - 1);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_NORMAL], x, y, x + width - 1, y);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_NORMAL], x, y, x, y + height - 1);
 
-                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x + 1, y + height - 1, x + width - 1, y + height - 1);
-                    gdk_draw_line(window, style->bg_gc[GTK_STATE_ACTIVE], x + width - 1, y + 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_NORMAL], x + 1, y + height - 1, x + width - 1, y + height - 1);
+                    gdk_draw_line(window, style->bg_gc[GTK_STATE_NORMAL], x + width - 1, y + 1, x + width - 1, y + height - 1);
 
                     gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x, y);
                     gdk_draw_point(window, style->mid_gc[GTK_STATE_NORMAL], x + width - 1, y);
